from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User, Group
from django.contrib.sites.models import Site

from hashlib import sha1

from samklang_media.storage import UpdateIgnoreStorage
from samklang_utils import slugify

import os
from os.path import splitext

from taggit.managers import TaggableManager

def githash(data):
    """
    Hash the contents of a file like git does. Taken from
    http://stackoverflow.com/questions/552659/assigning-git-sha1s-without-git
    """

    s = sha1()
    s.update("blob %u\0" % len(data))
    s.update(data)
    return s.hexdigest()

def get_upload_to(instance, filename):
    """
    Generate funny file path / url
    """

    # TODO: attach celery command (if that's what it's called) to resize images or do other stuff
    # maybe it is possible to extend image or other models with fields for randomized parts of url

    hexdigest = githash(instance.file.read())
    folder1 = hexdigest[:2]
    folder2 = hexdigest[2:4]
    folder3 = hexdigest
    folder = os.path.join(folder1, folder2, folder3, "o")

    name, ext = splitext(filename)
    return os.path.join(folder, slugify(name) + ext)

class MediaBase(models.Model):
    """
    Base model for media types
    """

    file = models.FileField(upload_to=get_upload_to, storage=UpdateIgnoreStorage(), verbose_name=_('File'))
    filename = models.CharField(max_length=60, verbose_name=_('filename'))
    content_type = models.CharField(verbose_name=_('content type'), max_length=80, blank=True)
    content_category = models.SmallIntegerField(verbose_name=_('Content category'), blank=True)
    submit_date = models.DateTimeField(auto_now_add=True)
    site = models.ForeignKey(Site, verbose_name=_('site'), blank=True)
    user = models.ForeignKey(User, verbose_name=_('user'), blank=True)
    group = models.ForeignKey(Group, null=True, blank=True, verbose_name=_('Group'))
    show = models.BooleanField(_('show in lists'), default=False)
    tags = TaggableManager(_('tags'), blank=True, help_text=_("A comma-separated list of tags."))

    class Meta:
        abstract = True
        ordering = ["-submit_date"]

    def __unicode__(self):
        return self.filename

    @models.permalink
    def get_absolute_url(self):
        return ('media-file-detail', [self.pk])


class Document(MediaBase):
    """Generic document type"""


    class Meta:
        verbose_name, verbose_name_plural = _("document"), _("documents")
        db_table = 'samklang_media'



from django.forms import ModelForm
from uni_form.helper import FormHelper
from uni_form.layout import Layout, Fieldset, ButtonHolder, Submit, MultiField, Row, Div
from samklang_media.models import Document
from samklang_media.widgets import UploadWidget

class ImageForm(ModelForm):
    class Meta:
        model = Document
        fields = ('file', 'filename', 'tags', 'show', 'group')

class UploadForm(ModelForm):

    class Meta:
        model = Document
        fields = ('file',)
        widgets = {'file': UploadWidget(upload={'rowselector': 'div.ctrlHolder'})}

class ManageDocumentForm(ModelForm):
    class Meta:
        model = Document
        fields = ('filename','show','group','tags')

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.layout = Layout(
                Fieldset(
                    '',
                    'filename',
                    'tags',
                    Row(
                        'show',
                        'group',
                        css_class="share",
                        ),
                    )
        )
        #ButtonHolder(
                #Submit('submit', 'Save', css_class='button white')
            #)
        return super(ManageDocumentForm, self).__init__(*args, **kwargs)

class DocumentForm(ModelForm):
    class Meta:
        model = Document
        fields = ('file', 'filename', 'tags', 'show', 'group')

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.add_input(Submit('button', 'Submit'))
        return super(DocumentForm, self).__init__(*args, **kwargs)



from django import forms
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext as _

__all__ = ( 'UploadWidget', )

class UploadWidget(forms.ClearableFileInput):
    """
    Widget for background uploading of files
    """

    default_options = {
        'rowselector': 'p',
    }

    def __init__(self, *args, **kwargs):
        self.options = self.default_options.copy()
        if "upload" in kwargs:
            self.options.update(kwargs.pop("upload"))
        super(UploadWidget, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs):
        data = super(UploadWidget, self).render(name, value, attrs)
        self.options['id'] = attrs.get('id')

        javascript = """
<div id="upl_status"></div>
<script>
    document.addEvent('domready', function(){
        var uploader = new Uploader('%(id)s', { rowselector: '%(rowselector)s' });
    });
</script>
        """ % self.options
        return mark_safe(data + javascript)



from django.core.files.storage import FileSystemStorage

import os

class UpdateIgnoreStorage(FileSystemStorage):

    def get_available_name(self, name):
        return name

    def _save(self, name, content):
        """Replaces last part of filename with "original", saves it if it is
        not already saved, and makes a symlink to the intended filename. This
        way, a folder will have one real file, and one symlink for each
        uniquely given filename."""

        # replace basename with "original"
        filename = os.path.join(name.rsplit("/", 1)[0], "original")

        # save the file if it has not already been saved
        if not self.exists(filename):
            super(UpdateIgnoreStorage, self)._save(filename, content)

        # make symlink to the intended filename
        symlink_path = os.path.join(self.location, name)
        file_path = os.path.join(self.location, filename)
        if not os.path.exists(symlink_path):
            os.symlink(file_path, symlink_path)

        # return the symlink name given as method parameter: this is used in the database
        return name



from django.contrib import admin
from samklang_media.models import Document#, Image

class DocumentAdmin(admin.ModelAdmin):
    list_display = ('filename', 'user', 'group', 'submit_date')
    list_filter = ('submit_date', 'group', 'user')

admin.site.register(Document, DocumentAdmin)



from django import template

register = template.Library()

@register.simple_tag
def upload_js():
    return """
    <script id="template-upload" type="text/x-jquery-tmpl">
        <tr class="template-upload{{if error}} ui-state-error{{/if}}">
            <td class="preview"></td>
            <td class="name">${name}</td>
            <td class="size">${sizef}</td>
            {{if error}}
                <td class="error" colspan="2">Error:
                    {{if error === 'maxFileSize'}}File is too big
                    {{else error === 'minFileSize'}}File is too small
                    {{else error === 'acceptFileTypes'}}Filetype not allowed
                    {{else error === 'maxNumberOfFiles'}}Max number of files exceeded
                    {{else}}${error}
                    {{/if}}
                </td>
            {{else}}
                <td class="progress"><div></div></td>
                <td class="start"><button>Start</button></td>
            {{/if}}
            <td class="cancel"><button>Cancel</button></td>
        </tr>
    </script>
    <script id="template-download" type="text/x-jquery-tmpl">
        <tr class="template-download{{if error}} ui-state-error{{/if}}">
            {{if error}}
                <td></td>
                <td class="name">${name}</td>
                <td class="size">${sizef}</td>
                <td class="error" colspan="2">Error:
                    {{if error === 1}}File exceeds upload_max_filesize (php.ini directive)
                    {{else error === 2}}File exceeds MAX_FILE_SIZE (HTML form directive)
                    {{else error === 3}}File was only partially uploaded
                    {{else error === 4}}No File was uploaded
                    {{else error === 5}}Missing a temporary folder
                    {{else error === 6}}Failed to write file to disk
                    {{else error === 7}}File upload stopped by extension
                    {{else error === 'maxFileSize'}}File is too big
                    {{else error === 'minFileSize'}}File is too small
                    {{else error === 'acceptFileTypes'}}Filetype not allowed
                    {{else error === 'maxNumberOfFiles'}}Max number of files exceeded
                    {{else error === 'uploadedBytes'}}Uploaded bytes exceed file size
                    {{else error === 'emptyResult'}}Empty file upload result
                    {{else}}${error}
                    {{/if}}
                </td>
            {{else}}
                <td class="preview">
                    {{if thumbnail_url}}
                        <a href="${url}" target="_blank"><img src="${thumbnail_url}"></a>
                    {{/if}}
                </td>
                <td class="name">
                    <a href="${url}"{{if thumbnail_url}} target="_blank"{{/if}}>${name}</a>
                </td>
                <td class="size">${sizef}</td>
                <td colspan="2"></td>
            {{/if}}
            <td class="delete">
                <button data-type="${delete_type}" data-url="${delete_url}">Delete</button>
            </td>
        </tr>
    </script>
    """



from django.views.generic import ListView, CreateView, DeleteView, DetailView, UpdateView
from django.http import HttpResponse, HttpResponseRedirect
from django.core.urlresolvers import reverse
from django.utils import simplejson
from django.contrib.sites.models import Site
from django.contrib.auth.models import User
from django.contrib.auth.decorators import login_required
from django.utils.decorators import method_decorator
from django.forms.models import modelformset_factory
from django.db.models.query_utils import Q

from samklang_media.models import Document
from samklang_media.forms import *

from django.shortcuts import render_to_response
from django.template import RequestContext

import os
from taggit.models import Tag, TaggedItem
import magic

from datetime import datetime, timedelta
from django.conf import settings

#def images_json(request):
    #"""Return json data of images"""
    #images = Image.objects.all()
    #data = [{'id': img.id, 'url': img.file.url, 'filename': img.filename} for img in images]
    #return JSONResponse(data)

#class ImageListView(ListView):
    #model = Image
#
    #def get_context_data(self, **kwargs):
        #popup = self.request.GET.get('popup', False)
        #context = super(ImageListView, self).get_context_data(**kwargs)
        #context['popup'] = popup
        #return context

def upload_file(request):
    form = UploadForm()
    return render_to_response('samklang_media/document_new.html', {
        'form': form,
        }, context_instance=RequestContext(request))

class ImageCreateView(CreateView):
    model = Document
    template_name = 'samklang_media/image_new.html'
    form_class = ImageForm

    def form_valid(self, form):
        mime = magic.Magic(mime=True)
        self.object = form.save(commit=False)
        self.object.user = self.request.user
        self.object.content_type = mime.from_buffer(self.object.file.read(128))
        self.object.content_category = 1 # hardcode to "image"
        if hasattr(self.request, 'site'):
            self.object.site = self.request.site
        else:
            self.object.site = Site.objects.get(pk=1)
        self.object.save()
        return HttpResponseRedirect(reverse('media-image-list'))


class DocumentCreateView(CreateView):
    model = Document
    template_name = 'samklang_media/document_new.html'
    form_class = UploadForm

    def form_valid(self, form):
        if self.request.FILES:
            mime = magic.Magic(mime=True)
            for f in self.request.FILES.getlist('file'):
                fobj = Document()
                fobj.file = f
                fobj.filename = f.name
                fobj.content_type = mime.from_buffer(f.file.read(128))
                fobj.content_category = 0 # hardcode to "generic uncategorized document"
                if hasattr(self.request, 'site'):
                    fobj.site = self.request.site
                else:
                    fobj.site = Site.objects.get(pk=1)
                fobj.user = self.request.user
                fobj.save()
            return JSONResponse({})


    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(DocumentCreateView, self).dispatch(*args, **kwargs)




def upload_document(request):
    if request.method == "POST" and request.FILES and request.user.is_authenticated():
        mime = magic.Magic(mime=True)
        for f in request.FILES.getlist('file'):
            #filepath = os.path.join(settings.MEDIA_ROOT, 'uploads', f.name)
            #destination = open(filepath, 'wb+')
            #for chunk in f.chunks():
                #destination.write(chunk)
            #destination.close()
            fobj = Document()
            fobj.file = f
            fobj.filename = f.name
            fobj.content_type = mime.from_buffer(f.file.read(128))
            fobj.content_category = 1 # hardcode to "document"
            fobj.site = Site.objects.get(pk=1)
            fobj.user = request.user
            fobj.save()
        return JSONResponse({})
    else:
        form = UploadForm()
        return render_to_response('samklang_media/document_new.html', {
            'form': form,
            }, context_instance=RequestContext(request))

def manage_documents(request):
    DocumentFormset = modelformset_factory(Document, fields=("filename", "tags", "show", "group"), extra=0)
    queryset = Document.objects.filter(user=request.user, submit_date__gt=datetime.now()-timedelta(hours=1), show=False)
    if request.method == "POST":
        formset = DocumentFormset(request.POST, queryset=queryset)
        if formset.is_valid():
            formset.save()
            return HttpResponseRedirect(reverse('media-file-list'))
    else:
        formset = DocumentFormset(queryset=queryset)
    return render_to_response("samklang_media/manage_documents.html", {
        "formset": formset,
	}, context_instance=RequestContext(request))

class DocumentListView(ListView):
    model = Document

    def get_queryset(self):
        queryset = super(DocumentListView, self).get_queryset().filter(Q(group=None) | Q(group__user=self.request.user)).filter(show=True)
        tag_url = self.kwargs.get("tags", "")
        if tag_url:
            tag_list = tag_url.split("/")
            return queryset.filter(tags__name__in=tag_list).distinct()
        else:
            return queryset

class DocumentDetailView(DetailView):
    model = Document

    def get_queryset(self):
        return super(DocumentDetailView, self).get_queryset().filter(Q(group=None) | Q(group__user=self.request.user)).filter(show=True)


class DocumentUpdateView(UpdateView):
    model = Document
    form_class = DocumentForm

    def get_queryset(self):
        return super(DocumentUpdateView, self).get_queryset().filter(Q(group=None) | Q(group__user=self.request.user)).filter(show=True)


class DocumentOldCreateView(CreateView):
    model = Document
    form_class = UploadForm
    template_name = "samklang_media/document_new.html"

    def form_valid(self, form):
        self.object = form.save(commit=False)
        self.object.filename = self.request.FILES['file'].name
        self.object.user = self.request.user
        if hasattr(self.request, 'site'):
            self.object.site = self.request.site
        else:
            self.object.site = Site.objects.get(pk=1)
        self.object.save()
        return JSONResponse({})
        #return HttpResponseRedirect("/")#self.object.get_absolute_url())

    def form_invalid(self, form):
        print "FEIL"
        return JSONResponse({})

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(DocumentCreateView, self).dispatch(*args, **kwargs)


#class ImageCreateView(CreateView):
    #model = Image
    #form_class = SimpleImageForm
#
    #def form_valid(self, form):
        #self.object = form.save(commit=False)
        #self.object.filename = self.request.FILES['file'].name
        #self.object.user = self.request.user
        #if hasattr(self.request, 'site'):
            #self.object.site = self.request.site
        #else:
            #self.object.site = Site.objects.get(pk=1)
        #self.object.save()
#
        #filename = self.object.filename
        #object_url = self.object.file.url
        #delete_url = reverse('media-delete-image', args=[self.object.id])
        #data = [{'name': filename, 'url': object_url, 'thumbnail_url': object_url, 'delete_url': delete_url, 'delete_type': "DELETE"}]
        #return JSONResponse(data)
#
    #@method_decorator(login_required)
    #def dispatch(self, *args, **kwargs):
        #return super(ImageCreateView, self).dispatch(*args, **kwargs)


#class ImageDeleteView(DeleteView):
    #model = Image
#
    #def delete(self, request, *args, **kwargs):
        #self.object = self.get_object()
        #self.object.is_removed = True
        #self.object.save()
        #return JSONResponse(True)

class JSONResponse(HttpResponse):
    """JSON response class. This does not help browsers not liking application/json."""
    def __init__(self,obj='',json_opts={},mimetype="application/json",*args,**kwargs):
        content = simplejson.dumps(obj,**json_opts)
        super(JSONResponse,self).__init__(content,mimetype,*args,**kwargs)



#!/usr/bin/env python
from distutils.core import setup

setup(
        name='samklang-media',
        version="0.4.0",
        author='Sigurd Gartmann',
        author_email='sigurdga-samklang@sigurdga.no',
        url='http://github.com/sigurdga/samklang-media',
        description='Uploading and file storage for samklang',
        long_description=open('README.txt').read(),
        license="AGPL",
        packages = ['samklang_media', 'samklang_media.templatetags', 'samklang_media.migrations'],
        package_data = {'samklang_media': ['templates/samklang_media/*.html', 'locale/*/LC_MESSAGES/django.*o', 'static/js/*.js']},
        install_requires=['python-magic>=0.4'],
        classifiers=[
                "Development Status :: 3 - Alpha",
                "License :: OSI Approved :: GNU Affero General Public License v3",
                "Intended Audience :: Developers",
                "Framework :: Django",
                "Environment :: Web Environment",
                "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
                ]
        )



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Document'
        db.create_table('samklang_media', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('file', self.gf('django.db.models.fields.files.FileField')(max_length=100)),
            ('filename', self.gf('django.db.models.fields.CharField')(max_length=60)),
            ('content_type', self.gf('django.db.models.fields.CharField')(max_length=80, blank=True)),
            ('content_category', self.gf('django.db.models.fields.SmallIntegerField')(blank=True)),
            ('submit_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('site', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['sites.Site'], blank=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], blank=True)),
            ('group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.Group'], null=True, blank=True)),
            ('show', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('samklang_media', ['Document'])


    def backwards(self, orm):
        
        # Deleting model 'Document'
        db.delete_table('samklang_media')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'samklang_media.document': {
            'Meta': {'object_name': 'Document', 'db_table': "'samklang_media'"},
            'content_category': ('django.db.models.fields.SmallIntegerField', [], {'blank': 'True'}),
            'content_type': ('django.db.models.fields.CharField', [], {'max_length': '80', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
            'filename': ('django.db.models.fields.CharField', [], {'max_length': '60'}),
            'group': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.Group']", 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'show': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sites.Site']", 'blank': 'True'}),
            'submit_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'blank': 'True'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'taggit.tag': {
            'Meta': {'object_name': 'Tag'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '100', 'db_index': 'True'})
        },
        'taggit.taggeditem': {
            'Meta': {'object_name': 'TaggedItem'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'taggit_taggeditem_tagged_items'", 'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'tag': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'taggit_taggeditem_items'", 'to': "orm['taggit.Tag']"})
        }
    }

    complete_apps = ['samklang_media']



from django.conf.urls.defaults import *
from samklang_media.views import *

urlpatterns = patterns('',
    #(r'^images.json$', images_json, {}),
    #(r'^image/new$', ImageCreateView.as_view(), {}, 'media-new-image'),
    #(r'^n/$', DocumentCreateView.as_view(), {}, 'media-new'),
    url(r'^n/$', upload_document, name="media-file-new"),
    url(r'^m/$', manage_documents, name="media-file-manage"),
    url(r'^s/(?P<pk>\d+)/$', DocumentDetailView.as_view(), name="media-file-detail"),
    url(r'^e/(?P<pk>\d+)/$', DocumentUpdateView.as_view(), name="media-file-edit"),
    url(r'^d/$', DocumentListView.as_view(queryset=Document.objects.filter(show=False)), name="media-file-unpublished"),
    url(r'^images/new/$', ImageCreateView.as_view(), name="media-image-new"),
    url(r'^images/$', DocumentListView.as_view(template_name='samklang_media/image_list.html'), name="media-image-list"),
    url(r'^(?:(?P<tags>.*)|)$', DocumentListView.as_view(), name="media-file-list"),
    #(r'^image/delete/(?P<pk>\d+)$', ImageDeleteView.as_view(), {}, 'media-delete-image'),
)
